def initial_options(shake_towards_roots:bool =True):
    return {
        "layout": {
            "hierarchical": {
                "enabled": True,
                "direction": "LR",
                "sortMethod": "directed",
                "shakeTowards": "roots" if shake_towards_roots else "leaves",
                "nodeSpacing": 1,
                "treeSpacing": 200,
                "levelSeparation": 300,
                "blockShifting": True,
                "edgeMinimization": True,
                "parentCentralization": True,
            }
        },
        "interaction": {
            "dragNodes": True,
            "dragView": True,
            "hover": True,
            "hoverConnectedEdges": True,
            "keyboard": {
                "enabled": True,
                "speed": {"x": 10, "y": 10, "zoom": 0.02},
                "bindToWindow": True,
            },
            "multiselect": True,
            "navigationButtons": False,
            "selectable": True,
            "selectConnectedEdges": True,
            "tooltipDelay": 150,
            "zoomView": True,
        },
        "physics": {
            "enabled": True,
            "solver": "hierarchicalRepulsion",
            "barnesHut": {
                "gravitationalConstant": -2000,
                "centralGravity": 0.3,
                "springLength": 95,
                "springConstant": 0.04,
                "damping": 0.09,
                "avoidOverlap": 0,
            },
            "forceAtlas2Based": {
                "gravitationalConstant": -50,
                "centralGravity": 0.01,
                "springLength": 100,
                "springConstant": 0.08,
                "damping": 0.4,
                "avoidOverlap": 0,
            },
            "hierarchicalRepulsion": {
                "centralGravity": 0.3,
                "springLength": 150,
                "springConstant": 0.015,
                "nodeDistance": 140,
                "damping": 0.15,
                "avoidOverlap": 1,
            },
            "repulsion": {
                "centralGravity": 0.2,
                "springLength": 200,
                "springConstant": 0.05,
                "nodeDistance": 100,
                "damping": 0.09,
            },
            "stabilization": {
                "enabled": True,
                "iterations": 1000,
                "updateInterval": 25,
                "fit": True,
            },
            "adaptiveTimestep": True,
            "minVelocity": 0.75,
            "timestep": 0.5,
        },
        "edges": {
            "arrows": {"to": {"enabled": True, "scaleFactor": 0.5}},
            "color": {"inherit": False},
            "smooth": {
                "enabled": True,
                "type": "cubicBezier",
                "forceDirection": "horizontal",
                "roundness": 0.2,
            },
            "width": 1.5,
            "selectionWidth": 2.5,
            "hoverWidth": 2.5,
            "widthConstraint": False,
        },
        "nodes": {
            "borderWidth": 1,
            "borderWidthSelected": 3,
            "font": {"size": 12, "face": "arial", "color": "#343434"},
            "scaling": {
                "min": 10,
                "max": 45,
                "label": {"enabled": True, "min": 10, "max": 20},
            },
            "shape": "dot",
            "shapeProperties": {"interpolation": False},
            "shadow": {"enabled": False, "size": 10, "x": 5, "y": 5},
        },
    }